<?php
/** Don't load directly */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'foxiz_render_footer' ) ) :
	function foxiz_render_footer() {

		foxiz_footer_top();

		$layout     = foxiz_get_option( 'footer_layout' );
		$classes    = array( 'footer-wrap rb-section' );
		$background = foxiz_get_option( 'footer_background' );

		if ( foxiz_get_option( 'footer_color_scheme' ) ) {
			$classes[] = 'light-scheme';
		}
		if ( foxiz_get_option( 'footer_column_border' ) ) {
			$classes[] = 'has-border';
		}
		if ( foxiz_get_option( 'footer_dot' ) ) {
			$classes[] = 'left-dot';
		}
		if ( ! empty( $background['background-color'] ) || ! empty( $background['background-attachment'] ) ) {
			$classes[] = 'footer-has-bg';
		}
		if ( ! empty( $layout ) && 'shortcode' == $layout ) {
			$classes[] = 'footer-etemplate';
		} ?>
		<footer class="<?php echo implode( ' ', $classes ); ?>">
			<?php if ( 'none' != $layout ) {
				if ( ! empty( $layout ) && 'shortcode' == $layout ) {
					echo do_shortcode( foxiz_get_option( 'footer_template_shortcode' ) );
				} else {
					foxiz_render_footer_widgets( $layout );
				}
			}
			foxiz_footer_copyright(); ?>
		</footer>
		<?php
	}
endif;

if ( ! function_exists( 'foxiz_footer_top' ) ) {
	function foxiz_footer_top() {

		if ( is_active_sidebar( 'foxiz_sidebar_fw_footer' ) )  : ?>
			<aside class="rb-section fw-widget top-footer edge-padding">
				<div class="top-footer-inner">
					<?php dynamic_sidebar( 'foxiz_sidebar_fw_footer' ); ?>
				</div>
			</aside>
		<?php endif;
	}
}

if ( ! function_exists( 'foxiz_render_footer_widgets' ) ) {
	/**
	 * @param $layout
	 */
	function foxiz_render_footer_widgets( $layout ) {
		if ( ! foxiz_get_footer_widgets( $layout ) ) {
			return false;
		}
		$classes = array( 'footer-columns rb-columns is-gap-25 rb-container edge-padding' );
		switch ( $layout ) {
			case 5 :
				$classes[] = 'footer-5c';
				break;
			case 51:
				$classes[] = 'footer-51c';
				break;
			case 3:
				$classes[] = 'footer-3c';
				break;
			default:
				$classes[] = 'footer-4c';
		} ?>
		<div class="<?php echo implode( ' ', $classes ); ?>">
			<div class="block-inner">
				<?php echo foxiz_get_footer_widgets( $layout ); ?>
			</div>
		</div>
	<?php }
}

if ( ! function_exists( 'foxiz_get_footer_widgets' ) ) {
	/**
	 * @param $layout
	 *
	 * @return false|string
	 */
	function foxiz_get_footer_widgets( $layout ) {
		ob_start();

		if ( is_active_sidebar( 'foxiz_sidebar_footer_1' ) ) {
			echo '<div class="footer-col">';
			dynamic_sidebar( 'foxiz_sidebar_footer_1' );
			echo '</div>';
		}
		if ( is_active_sidebar( 'foxiz_sidebar_footer_2' ) ) {
			echo '<div class="footer-col">';
			dynamic_sidebar( 'foxiz_sidebar_footer_2' );
			echo '</div>';
		}
		if ( is_active_sidebar( 'foxiz_sidebar_footer_3' ) ) {
			echo '<div class="footer-col">';
			dynamic_sidebar( 'foxiz_sidebar_footer_3' );
			echo '</div>';
		}
		if ( is_active_sidebar( 'foxiz_sidebar_footer_4' ) && ( '3' != $layout ) ) {
			echo '<div class="footer-col">';
			dynamic_sidebar( 'foxiz_sidebar_footer_4' );
			echo '</div>';
		}
		if ( is_active_sidebar( 'foxiz_sidebar_footer_5' ) && ! empty( $layout ) && ( '5' == $layout || '51' == $layout ) ) {
			echo '<div class="footer-col">';
			dynamic_sidebar( 'foxiz_sidebar_footer_5' );
			echo '</div>';
		}

		return ob_get_clean();
	}
}

if ( ! function_exists( 'foxiz_footer_copyright' ) ) :
	function foxiz_footer_copyright() {

		if ( ! foxiz_get_footer_copyright() ) {
			return false;
		}
		$classes = 'footer-copyright';
		if ( foxiz_get_option( 'footer_bottom_center' ) ) {
			$classes .= ' footer-bottom-centered';
		} ?>
		<div class="<?php echo esc_attr( $classes ); ?>">
			<div class="rb-container edge-padding">
				<?php echo foxiz_get_footer_copyright(); ?>
			</div>
		</div>
	<?php }
endif;

if ( ! function_exists( 'foxiz_get_footer_copyright' ) ) {
	function foxiz_get_footer_copyright() {

		$copyright = foxiz_get_option( 'copyright' );
		$menu      = foxiz_get_option( 'footer_menu' );
		$social    = foxiz_get_option( 'footer_social' );
		$logo      = foxiz_get_option( 'footer_logo' );
		$dark_logo = foxiz_get_option( 'dark_footer_logo' );

		ob_start();
		if ( ! empty( $logo['url'] ) || ! empty( $social ) ) : ?>
			<div class="bottom-footer-section">
				<?php if ( ! empty( $logo['url'] ) ) : ?>
					<a class="footer-logo" href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php bloginfo( 'name' ); ?>">
						<?php echo foxiz_get_logo_html( $logo );
						if ( foxiz_dark_mode() ) {
							if ( empty( $dark_logo['url'] ) ) {
								$dark_logo = $logo;
							}
							echo foxiz_get_logo_html( $dark_logo, false, 'logo-dark', 'dark' );
						} ?>
					</a>
				<?php endif;
				if ( ! empty( $social ) ) : ?>
					<div class="footer-social-list">
						<span class="footer-social-list-title h6"><?php foxiz_html_e( 'Follow US', 'foxiz' ); ?></span>
						<?php echo foxiz_get_social_list( foxiz_get_option() ); ?>
					</div>
				<?php endif; ?>
			</div>
		<?php endif;
		if ( ! empty( $copyright ) || ! empty( $menu ) ) : ?>
			<div class="copyright-inner">
				<?php
				if ( ! empty( $copyright ) ) {
					echo '<div class="copyright">' . wp_kses( wpautop( $copyright ), 'foxiz' ) . '</div>';
				}
				if ( ! empty( $menu ) ) {
					wp_nav_menu( array(
						'menu'        => $menu,
						'menu_id'     => 'copyright-menu',
						'menu_class'  => 'copyright-menu',
						'container'   => false,
						'depth'       => 1,
						'echo'        => true,
						'fallback_cb' => '__return_false',
					) );
				} ?>
			</div>
		<?php endif;

		return ob_get_clean();
	}
}